@@ -9,6 +9,7 @@
 #include "alarmchecker.h"
 #include <QDebug>
 #include <KCalendarCore/Todo>
+#include <KCalendarCore/MemoryCalendar>
 #include <QFile>
 #include <QFileInfo>
 #include <QStandardPaths>
@@ -24,7 +25,7 @@ LocalCalendar::LocalCalendar(QObject *parent)
 
 LocalCalendar::~LocalCalendar() = default;
 
-MemoryCalendar::Ptr LocalCalendar::memorycalendar()
+Calendar::Ptr LocalCalendar::calendar()
 {
     reloadStorage();
     return m_calendar;
@@ -35,20 +36,20 @@ QString LocalCalendar::name() const
     return m_name;
 }
 
-void LocalCalendar::setName(QString calendarName)
+void LocalCalendar::setName(QString &calendarName)
 {
     if (m_name != calendarName) {
         loadCalendar(calendarName);
     }
 }
 
-void LocalCalendar::setMemorycalendar(MemoryCalendar::Ptr memoryCalendar)
+void LocalCalendar::setCalendar(Calendar::Ptr calendar)
 {
-    if (m_calendar != memoryCalendar) {
-        m_calendar = memoryCalendar;
+    if (m_calendar != calendar) {
+        m_calendar = calendar;
     }
 
-    Q_EMIT memorycalendarChanged();
+    Q_EMIT calendarChanged();
 }
 
 int LocalCalendar::todosCount(const QDate &date) const
@@ -114,43 +115,6 @@ QVariantMap LocalCalendar::canCreateFile(const QString &calendarName)
     return result;
 }
 
-QVariantMap LocalCalendar::importCalendar(const QString &calendarName, const QUrl &sourcePath)
-{
-    QVariantMap result;
-    result["success"] = QVariant(false);
-
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZoneId()));
-    FileStorage::Ptr storage(new FileStorage(calendar));
-
-    QVariantMap canCreateCheck = canCreateFile(calendarName);
-    if (!(canCreateCheck["success"].toBool())) {
-        result["reason"] = QVariant(canCreateCheck["reason"].toString());
-
-        return result;
-    }
-
-    storage->setFileName(sourcePath.toString(QUrl::RemoveScheme));
-
-    if (!(storage->load())) {
-        result["reason"] = QVariant(QString(i18n("The calendar file is not valid")));
-
-        return result;
-    }
-
-    storage->setFileName(canCreateCheck["targetPath"].toString());
-
-    if (!(storage->save())) {
-        result["reason"] = QVariant(QString(i18n("The calendar file cannot be saved")));
-
-        return result;
-    }
-
-    result["success"] = QVariant(true);
-    result["reason"] = QVariant(QString());
-
-    return result;
-}
-
 void LocalCalendar::loadCalendar(const QString &calendarName)
 {
     m_fullpath = m_config->calendarFile(calendarName);
@@ -163,11 +127,6 @@ void LocalCalendar::loadCalendar(const QString &calendarName)
     }
 }
 
-QString LocalCalendar::fileNameFromUrl(const QUrl &sourcePath)
-{
-    return sourcePath.fileName();
-}
-
 void LocalCalendar::reloadStorage()
 {
     if (m_fullpath.isEmpty()) {
@@ -177,12 +136,10 @@ void LocalCalendar::reloadStorage()
 
     QFileInfo storageFileInfo { m_fullpath };
 
-    qDebug() << "Last memory-fs sync: " << m_fs_sync_dt;
-    qDebug() << "Filed modified: " << storageFileInfo.lastModified();
-
-    if (storageFileInfo.lastModified() <= m_fs_sync_dt) {
-        qDebug() << "Reload not needed, the calendar file has not been updated";
-    } else {
+    if (storageFileInfo.lastModified() > m_fs_sync_dt) {
+        qDebug() << "Last memory-fs sync: " << m_fs_sync_dt;
+        qDebug() << "Filed modified: " << storageFileInfo.lastModified();
+        qDebug() << "Reload storage";
         loadStorage();
     }
 }
@@ -194,7 +151,7 @@ bool LocalCalendar::loadStorage()
         return false;
     }
 
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZoneId()));
+    Calendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZoneId()));
     FileStorage::Ptr storage(new FileStorage(calendar));
     storage->setFileName(m_fullpath);
 
@@ -211,9 +168,38 @@ bool LocalCalendar::loadStorage()
         m_calendar = calendar;
         m_fs_sync_dt = QDateTime::currentDateTime();
         m_alarm_checker->scheduleAlarmCheck();
-        Q_EMIT memorycalendarChanged();
+        Q_EMIT calendarChanged();
         return true;
     }
 
     return false;
 }
+
+QString LocalCalendar::ownerName() const
+{
+    return m_config->ownerName(m_name);
+}
+
+QString LocalCalendar::ownerEmail() const
+{
+    return m_config->ownerEmail(m_name);
+}
+
+bool LocalCalendar::isExternal() const
+{
+    return m_config->isExternal(m_name);
+}
+
+void LocalCalendar::setOwnerName(QString &ownerName)
+{
+    m_config->setOwnerName(m_name, ownerName);
+
+    Q_EMIT ownerNameChanged();
+}
+
+void LocalCalendar::setOwnerEmail(QString &ownerEmail)
+{
+    m_config->setOwnerEmail(m_name, ownerEmail);
+
+    Q_EMIT ownerEmailChanged();
+}
