@@ -5,23 +5,45 @@
  */
 
 #include <QApplication>
+#include <QGuiApplication>
+#include <QDir>
+#include <QDebug>
 #include <QQmlApplicationEngine>
 #include <QtQml>
 #include <QUrl>
 #include <QVariant>
+#include <QWindow>
 #include <KAboutData>
 #include <KLocalizedContext>
 #include <KLocalizedString>
-
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/Attendee>
+#ifndef Q_OS_ANDROID
+#include <KDBusService>
+#endif
 #include "calindoriconfig.h"
 #include "localcalendar.h"
-#include "eventcontroller.h"
-#include "todocontroller.h"
 #include "incidencealarmsmodel.h"
 #include "daysofmonthmodel.h"
 #include "recurrenceperiodmodel.h"
 #include "daysofmonthincidencemodel.h"
 #include "incidencemodel.h"
+#include "datahandler.h"
+#include "calendarcontroller.h"
+#include "attendeesmodel.h"
+
+void handleArgument(DataHandler *dataHandler, const QStringList &args)
+{
+    if (!args.isEmpty()) {
+        const auto file = args.constFirst();
+        const auto localUrl = QUrl::fromLocalFile(file);
+        if (QFile::exists(localUrl.toLocalFile())) {
+            dataHandler->importFromUrl(localUrl);
+        } else {
+            dataHandler->importFromUrl(QUrl::fromUserInput(file));
+        }
+    }
+}
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
@@ -29,7 +51,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("calindori");
 
-    KAboutData aboutData(QStringLiteral("calindori"), i18n("Calindori"), QStringLiteral("1.3.0"), i18nc("@title", "Calendar application"), KAboutLicense::GPL_V3, i18nc("@info:credit", "(c) 2018-2020 The Calindori Team"));
+    KAboutData aboutData(QStringLiteral("calindori"), i18n("Calindori"), QStringLiteral("1.4.0"), i18nc("@title", "Calendar application"), KAboutLicense::GPL_V3, i18nc("@info:credit", "(c) 2018-2021 The Calindori Team"));
 
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setProductName(QByteArray("calindori"));
@@ -47,6 +69,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+#ifndef Q_OS_ANDROID
+    KDBusService service(KDBusService::Unique);
+#endif
+
     QApplication::setApplicationName(aboutData.componentName());
     QApplication::setApplicationDisplayName(aboutData.displayName());
     QApplication::setOrganizationDomain(aboutData.organizationDomain());
@@ -54,23 +80,52 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     qmlRegisterType<CalindoriConfig>("org.kde.calindori", 0, 1, "CalindoriConfig");
     qmlRegisterType<LocalCalendar>("org.kde.calindori", 0, 1, "LocalCalendar");
-    qmlRegisterType<EventController>("org.kde.calindori", 0, 1, "EventController");
-    qmlRegisterType<TodoController>("org.kde.calindori", 0, 1, "TodoController");
     qmlRegisterType<IncidenceAlarmsModel>("org.kde.calindori", 0, 1, "IncidenceAlarmsModel");
     qmlRegisterType<DaysOfMonthModel>("org.kde.calindori", 0, 1, "DaysOfMonthModel");
     qmlRegisterType<ReccurencePeriodModel>("org.kde.calindori", 0, 1, "ReccurencePeriodModel");
     qmlRegisterType<DaysOfMonthIncidenceModel>("org.kde.calindori", 0, 1, "DaysOfMonthIncidenceModel");
     qmlRegisterType<IncidenceModel>("org.kde.calindori", 0, 1, "IncidenceModel");
+    qmlRegisterType<AttendeesModel>("org.kde.calindori", 0, 1, "AttendeesModel");
+    qmlRegisterUncreatableType<KCalendarCore::Incidence>("org.kde.calindori", 0, 1, "CalendarIncidence", "Use Enums");
+    qmlRegisterUncreatableType<KCalendarCore::Attendee>("org.kde.calindori", 0, 1, "CalendarAttendee", "Use Enums");
+
+    qmlRegisterSingletonType<DataHandler>("org.kde.calindori", 0, 1, "DataHandler", [](QQmlEngine * engine, QJSEngine *) -> QObject* {
+        auto instance = DataHandler::instance();
+        engine->setObjectOwnership(instance, QQmlEngine::CppOwnership);
+
+        return instance;
+    });
+
+    static CalendarController *s_calendar_controller = nullptr;
+    qmlRegisterSingletonType<CalendarController>("org.kde.calindori", 0, 1, "CalendarController", [](QQmlEngine * engine, QJSEngine *) -> QObject* {
+        engine->setObjectOwnership(s_calendar_controller, QQmlEngine::CppOwnership);
+
+        return s_calendar_controller;
+    });
+
+    CalendarController calendarController;
+    s_calendar_controller = &calendarController;
+
+    DataHandler dataHandler;
+    dataHandler.setCalendarController(&calendarController);
+
+#ifndef Q_OS_ANDROID
+    QObject::connect(&service, &KDBusService::activateRequested, [&parser, &dataHandler](const QStringList & args, const QString & workingDir) {
+        qDebug() << "remote activation" << args << workingDir;
+        if (!args.isEmpty()) {
+            QDir::setCurrent(workingDir);
+            parser.parse(args);
+            handleArgument(&dataHandler, parser.positionalArguments());
+        }
+        if (!QGuiApplication::allWindows().isEmpty()) {
+            QGuiApplication::allWindows().at(0)->requestActivate();
+        }
+    });
+#endif
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
-    TodoController todoController;
-    engine.rootContext()->setContextProperty(QStringLiteral("_todoController"), &todoController);
-
-    EventController eventController;
-    engine.rootContext()->setContextProperty(QStringLiteral("_eventController"), &eventController);
-
     ReccurencePeriodModel repeatModel;
     engine.rootContext()->setContextProperty(QStringLiteral("_repeatModel"), &repeatModel);
 
@@ -86,6 +141,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return -1;
     }
 
+    handleArgument(&dataHandler, parser.positionalArguments());
+
     int ret = app.exec();
     return ret;
 }
